@@ -140,11 +140,11 @@ Getopt_long::report (Errorcod c)
   switch (c)
     {
     case E_ARGEXPECT:
-      str += _f ("Option `%s' requires an argument",
+      str += _f ("option `%s' requires an argument",
 	found_option_l_->str ());
       break;
     case  E_NOARGEXPECT:
-      str += _f ("Option `%s' doesn't allow an argument",
+      str += _f ("option `%s' doesn't allow an argument",
 	found_option_l_->str ());
       break;
     case E_UNKNOWNOPTION:
@@ -157,6 +157,7 @@ Getopt_long::report (Errorcod c)
     case E_ILLEGALARG:
       str += _f ("invalid argument `%s' to option `%s'",
         optional_argument_ch_C_, found_option_l_->str ());
+      break;
     default:
       assert (false);
     }
