@@ -4,13 +4,38 @@
   (c)  1997--2000 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 
-#include "note-head.hh"
-#include "note-heads-engraver.hh"
+#include "rhythmic-head.hh"
+#include "engraver.hh"
 #include "paper-def.hh"
 #include "musical-request.hh"
 #include "dots.hh"
 #include "dot-column.hh"
 #include "staff-symbol-referencer.hh"
+#include "engraver.hh"
+#include "pqueue.hh"
+
+/**
+  make balls and rests
+ */
+class Note_heads_engraver : public Engraver
+{
+  Link_array<Rhythmic_head> note_p_arr_;
+  Link_array<Item> dot_p_arr_;
+  Link_array<Note_req> note_req_l_arr_;
+  Moment note_end_mom_;
+public:
+  VIRTUAL_COPY_CONS(Translator);
+  Note_heads_engraver();
+  
+protected:
+  virtual bool do_try_music (Music *req_l) ;
+  virtual void do_process_music();
+  virtual void do_pre_move_processing();
+};
+
+
+
+
 
 Note_heads_engraver::Note_heads_engraver()
 {
@@ -60,7 +85,7 @@ Note_heads_engraver::do_process_music()
   
   for (int i=0; i < note_req_l_arr_.size (); i++)
     {
-      Note_head *note_p  = new Note_head (get_property ("basicNoteHeadProperties"));
+      Rhythmic_head *note_p  = new Rhythmic_head (get_property ("basicNoteHeadProperties"));
       
       Staff_symbol_referencer_interface si (note_p);
       si.set_interface ();
@@ -73,17 +98,19 @@ Note_heads_engraver::do_process_music()
 
       if (note_req_l->duration_.dots_i_)
 	{
-	   Item * d = new Item (get_property ("basicDotsProperties"));
+	  Item * d = new Item (get_property ("basicDotsProperties"));
 
 	  Staff_symbol_referencer_interface sd (d);
 	  sd.set_interface ();
 	  
-	  note_p->add_dots (d);
+	  note_p->set_dots (d);
 	  
 	  if (note_req_l->duration_.dots_i_
 	      != gh_scm2int (d->get_elt_property ("dot-count")))
 	    d->set_elt_property ("dot-count", gh_int2scm (note_req_l->duration_.dots_i_));
-	  
+
+	  d->set_parent (note_p, Y_AXIS);
+	  d->add_offset_callback (Dots::quantised_position_callback, Y_AXIS);
 	  announce_element (Score_element_info (d,0));
 	  dot_p_arr_.push (d);
 	}
